@@ -2,9 +2,10 @@
  * input_ps.c: PS demux and packet management
  *****************************************************************************
  * Copyright (C) 1998, 1999, 2000 VideoLAN
- * $Id: input_ps.c,v 1.10 2001/03/02 15:51:22 massiot Exp $
+ * $Id: input_ps.c,v 1.13 2001/04/05 16:37:15 asmax Exp $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
+ *          Cyril Deguet <asmax@via.ecp.fr>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -371,7 +372,7 @@ static int PSRead( input_thread_t * p_input,
                 /* It is common for MPEG-1 streams to pad with zeros
                  * (although it is forbidden by the recommendation), so
                  * don't bother everybody in this case. */
-                intf_WarnMsg( 1, "Garbage at input (%x)", i_startcode );
+                intf_WarnMsg( 1, "Garbage at input (%.8x)", i_startcode );
             }
 
             while( (i_startcode & 0xFFFFFF00) != 0x100L )
@@ -477,6 +478,7 @@ static void PSSeek( input_thread_t * p_input, off_t i_position )
  * Packet management utilities
  */
 
+
 /*****************************************************************************
  * NewPacket: allocates a data packet
  *****************************************************************************/
@@ -569,4 +571,3 @@ static void DeletePES( void * p_garbage, pes_packet_t * p_pes )
     free( p_pes );
 }
 
-
