@@ -4,7 +4,7 @@
  * decoders.
  *****************************************************************************
  * Copyright (C) 1998, 1999, 2000 VideoLAN
- * $Id: input.c,v 1.87 2001/02/20 09:10:36 sam Exp $
+ * $Id: input.c,v 1.95 2001/04/08 09:04:33 stef Exp $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *
@@ -36,6 +36,17 @@
 #include <string.h>
 #include <errno.h>
 
+/* Network functions */
+
+#if !defined( SYS_BEOS ) && !defined( SYS_NTO )
+#include <netdb.h>                                             /* hostent ... */
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
+#include <sys/types.h>
+#include <sys/socket.h>
+#endif
+
 #ifdef STATS
 #   include <sys/times.h>
 #endif
@@ -44,10 +55,11 @@
 #include "common.h"
 #include "threads.h"
 #include "mtime.h"
+#include "netutils.h"
 #include "modules.h"
 
 #include "intf_msg.h"
-#include "intf_plst.h"
+#include "intf_playlist.h"
 
 #include "stream_control.h"
 #include "input_ext-intf.h"
@@ -58,6 +70,9 @@
 
 #include "main.h"
 
+ /* #include <netutils.h> */
+
+
 /*****************************************************************************
  * Local prototypes
  *****************************************************************************/
@@ -89,6 +104,9 @@ input_thread_t *input_CreateThread ( playlist_item_t *p_item, int *pi_status )
         return( NULL );
     }
 
+    /* Packets read once */
+    p_input->i_read_once = INPUT_READ_ONCE;
+
     /* Initialize thread properties */
     p_input->b_die              = 0;
     p_input->b_error            = 0;
@@ -193,7 +211,6 @@ void input_DestroyThread( input_thread_t *p_input, int *pi_status )
  *****************************************************************************/
 static void RunThread( input_thread_t *p_input )
 {
-    data_packet_t *         pp_packets[INPUT_READ_ONCE];
     int                     i_error, i;
 
     if( InitThread( p_input ) )
@@ -209,6 +226,7 @@ static void RunThread( input_thread_t *p_input )
 
     while( !p_input->b_die && !p_input->b_error && !p_input->b_eof )
     {
+        data_packet_t *         pp_packets[p_input->i_read_once];
 
 #ifdef STATS
         p_input->c_loops++;
@@ -241,7 +259,7 @@ static void RunThread( input_thread_t *p_input )
         i_error = p_input->pf_read( p_input, pp_packets );
 
         /* Demultiplex read packets. */
-        for( i = 0; i < INPUT_READ_ONCE && pp_packets[i] != NULL; i++ )
+        for( i = 0; i < p_input->i_read_once && pp_packets[i] != NULL; i++ )
         {
             p_input->pf_demux( p_input, pp_packets[i] );
         }
@@ -295,7 +313,8 @@ static int InitThread( input_thread_t * p_input )
 
     if( p_input->p_input_module == NULL )
     {
-        intf_ErrMsg( "input error: no suitable input module" );
+        intf_ErrMsg( "input error: no suitable input module for `%s'",
+                     p_input->p_source );
         return( -1 );
     }
 
@@ -305,6 +324,7 @@ static int InitThread( input_thread_t * p_input )
     p_input->pf_close         = f.pf_close;
     p_input->pf_end           = f.pf_end;
     p_input->pf_read          = f.pf_read;
+    p_input->pf_set_area      = f.pf_set_area;
     p_input->pf_demux         = f.pf_demux;
     p_input->pf_new_packet    = f.pf_new_packet;
     p_input->pf_new_pes       = f.pf_new_pes;
@@ -313,7 +333,6 @@ static int InitThread( input_thread_t * p_input )
     p_input->pf_rewind        = f.pf_rewind;
     p_input->pf_seek          = f.pf_seek;
 #undef f
-
     p_input->pf_open( p_input );
 
     if( p_input->b_error )
@@ -326,6 +345,14 @@ static int InitThread( input_thread_t * p_input )
 
     p_input->pf_init( p_input );
 
+    if( p_input->b_error )
+    {
+        /* We barfed -- exit nicely */
+        p_input->pf_close( p_input );
+        module_Unneed( p_main->p_bank, p_input->p_input_module );
+        return( -1 );
+    }
+
     *p_input->pi_status = THREAD_READY;
 
     return( 0 );
@@ -423,16 +450,16 @@ void input_FileOpen( input_thread_t * p_input )
             /* get rid of the 'dvd:' stuff and try again */
             psz_name += 4;
             i_stat = stat( psz_name, &stat_info );
-	}
-	else if( ( i_size > 5 )
+        }
+        else if( ( i_size > 5 )
                  && !strncasecmp( psz_name, "file:", 5 ) )
         {
             /* get rid of the 'file:' stuff and try again */
             psz_name += 5;
             i_stat = stat( psz_name, &stat_info );
-	}
+        }
 
-	if( i_stat == (-1) )
+        if( i_stat == (-1) )
         {
             intf_ErrMsg( "input error: cannot stat() file `%s' (%s)",
                          psz_name, strerror(errno));
@@ -494,3 +521,119 @@ void input_FileClose( input_thread_t * p_input )
     return;
 }
 
+
+#if !defined( SYS_BEOS ) && !defined( SYS_NTO )
+/*****************************************************************************
+ * input_NetworkOpen : open a network socket 
+ *****************************************************************************/
+void input_NetworkOpen( input_thread_t * p_input )
+{
+ 
+    int                 i_option_value, i_port;
+    struct sockaddr_in  s_socket;
+    boolean_t           b_broadcast;
+    
+    /* FIXME : we don't handle channels for the moment */
+    
+    /* Get the remote server */
+    if( p_input->p_source == NULL )
+    {
+        p_input->p_source = main_GetPszVariable( INPUT_SERVER_VAR, 
+                                                 INPUT_SERVER_DEFAULT );
+    }
+    
+    /* Open a SOCK_DGRAM (UDP) socket, in the AF_INET domain, automatic (0)
+     * protocol */
+    p_input->i_handle = socket( AF_INET, SOCK_DGRAM, 0 );
+    if( p_input->i_handle == -1 )
+    {
+        intf_ErrMsg("NetworkOpen : can't create socket : %s", strerror(errno));
+        p_input->b_error = 1;
+        return;
+    }
+
+    /* We may want to reuse an already used socket */
+    i_option_value = 1;
+    if( setsockopt( p_input->i_handle, SOL_SOCKET, SO_REUSEADDR,
+                    &i_option_value,sizeof( i_option_value ) ) == -1 )
+    {
+        intf_ErrMsg("NetworkOpen : can't configure socket (SO_REUSEADDR: %s)",
+                    strerror(errno));
+        close( p_input->i_handle );
+        p_input->b_error = 1;
+        return;
+    }
+
+    /* Increase the receive buffer size to 1/2MB (8Mb/s during 1/2s) to avoid
+     * packet loss caused by scheduling problems */
+    i_option_value = 524288;
+    if( setsockopt( p_input->i_handle, SOL_SOCKET, SO_RCVBUF, &i_option_value,
+                    sizeof( i_option_value ) ) == -1 )
+    {
+        intf_ErrMsg("NetworkOpen : can't configure socket (SO_RCVBUF: %s)", 
+                    strerror(errno));
+        close( p_input->i_handle );
+        p_input->b_error = 1;
+        return;
+    }
+
+    /* Get details about what we are supposed to do */
+    b_broadcast = (boolean_t)main_GetIntVariable( INPUT_BROADCAST_VAR, 0 );
+    i_port = main_GetIntVariable( INPUT_PORT_VAR, INPUT_PORT_DEFAULT );
+
+    /* TODO : here deal with channel stufs */
+    
+    /* Build the local socket */
+    if ( network_BuildLocalAddr( &s_socket, i_port, b_broadcast ) 
+         == -1 )
+    {
+        close( p_input->i_handle );
+        p_input->b_error = 1;
+        return;
+    }
+    
+    /* Bind it */
+    if( bind( p_input->i_handle, (struct sockaddr *)&s_socket, 
+              sizeof( s_socket ) ) < 0 )
+    {
+        intf_ErrMsg("NetworkOpen: can't bind socket (%s)", strerror(errno));
+        close( p_input->i_handle );
+        p_input->b_error = 1;
+        return;
+    }
+
+    /* Build socket for remote connection */
+    if ( network_BuildRemoteAddr( &s_socket, p_input->p_source ) 
+         == -1 )
+    {
+        close( p_input->i_handle );
+        p_input->b_error = 1;
+        return;
+    }
+
+    /* And connect it ... should we really connect ? */
+    if( connect( p_input->i_handle, (struct sockaddr *) &s_socket,
+                 sizeof( s_socket ) ) == (-1) )
+    {
+        intf_ErrMsg("NetworkOpen: can't connect socket" );
+        close( p_input->i_handle );
+        p_input->b_error = 1;
+        return;
+    }
+
+    /* We can't pace control, but FIXME : bug in meuuh's code to sync PCR
+     * with the server. */
+    p_input->stream.b_pace_control = 1;
+    
+    return;
+}
+
+/*****************************************************************************
+ * input_NetworkClose : close a network socket
+ *****************************************************************************/
+void input_NetworkClose( input_thread_t * p_input )
+{
+    close( p_input->i_handle );
+    /* FIXME: deal with channels */
+}
+#endif
